ncplib
======

NCP library for Python 3, developed by `CRFS <https://www.crfs.com/>`_.

.. image:: https://travis-ci.org/CRFS/python3-ncplib.svg?branch=master
    :target: https://travis-ci.org/CRFS/python3-ncplib


Features
--------

-   `NCP client <https://ncplib.readthedocs.io/en/stable/client.html>`_.
-   `NCP server <https://ncplib.readthedocs.io/en/stable/server.html>`_.
-   Asynchronous connections via `asyncio <https://docs.python.org/3/library/asyncio.html>`_.


Resources
---------

-   `Documentation <https://ncplib.readthedocs.io/>`_ is on Read the Docs.
-   `Examples <https://github.com/CRFS/python3-ncplib/tree/master/examples>`_, `issue tracking <https://github.com/CRFS/python3-ncplib/issues>`_ and `source code <https://github.com/CRFS/python3-ncplib>`_ are on GitHub.
-   `Continuous integration <https://travis-ci.org/CRFS/python3-ncplib>`_ is on Travis CI.
